@@ -2,7 +2,7 @@ package Web::Request::Role::Response;
 
 # ABSTRACT: Generate various HTTP responses from a Web::Request
 
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 
 use 5.010;
 use Moose::Role;
@@ -11,7 +11,7 @@ use Plack::Response;
 sub redirect {
     my ( $self, $target, $status ) = @_;
 
-    if ( ref($target) ) {
+    if ( ref($target) eq 'HASH' ) {
         $target = $self->uri_for($target);
     }
     my $res = $self->new_response();
@@ -80,7 +80,7 @@ Web::Request::Role::Response - Generate various HTTP responses from a Web::Reque
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
